@@ -1,16 +1,18 @@
 use strict;
 use warnings;
-package OpenAPI::Modern; # git description: v0.044-4-gcba9f81
+package OpenAPI::Modern; # git description: v0.045-9-g275a796
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
-# ABSTRACT: Validate HTTP requests and responses against an OpenAPI document
-# KEYWORDS: validation evaluation JSON Schema OpenAPI Swagger HTTP request response
+# ABSTRACT: Validate HTTP requests and responses against an OpenAPI v3.1 document
+# KEYWORDS: validation evaluation JSON Schema OpenAPI v3.1 Swagger HTTP request response
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 
 use 5.020;
+use utf8;
 use Moo;
 use strictures 2;
-use experimental qw(signatures postderef);
+use stable 0.031 'postderef';
+use experimental 'signatures';
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
@@ -142,6 +144,9 @@ sub validate_request ($self, $request, $options = {}) {
 
     # 3.2 "Each template expression in the path MUST correspond to a path parameter that is included in
     # the Path Item itself and/or in each of the Path Item’s Operations."
+    # We could validate this at document parse time, except the path-item can also be reached via a
+    # $ref and the referencing path could be from another document and is therefore unknowable until
+    # runtime.
     foreach my $path_name (sort keys $path_captures->%*) {
       abort({ %$state, data_path => jsonp($state->{data_path}, qw(uri path), $path_name) },
           'missing path parameter specification for "%s"', $path_name)
@@ -224,6 +229,17 @@ sub validate_response ($self, $response, $options = {}) {
       return $self->_result($state, 1);
     }
 
+    if ($response->headers->header('Transfer-Encoding')) {
+      ()= E({ %$state, data_path => jsonp($state->{data_path}, qw(header Transfer-Encoding)) },
+        'RFC9112 §6.1-10: A server MUST NOT send a Transfer-Encoding header field in any response with a status code of 1xx (Informational) or 204 (No Content)')
+        if $response->is_info or $response->code == 204;
+
+      # connect method is not supported in openapi 3.1.0, but this may be possible in the future
+      ()= E({ %$state, data_path => jsonp($state->{data_path}, qw(header Transfer-Encoding)) },
+        'RFC9112 §6.1-10: A server MUST NOT send a Transfer-Encoding header field in any 2xx (Successful) response to a CONNECT request')
+        if $response->is_success and $method eq 'connect';
+    }
+
     my $response_name = first { exists $operation->{responses}{$_} }
       $response->code, substr(sprintf('%03s', $response->code), 0, -2).'XX', 'default';
 
@@ -696,11 +712,11 @@ __END__
 
 =head1 NAME
 
-OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI document
+OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI v3.1 document
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
